# Torr's Hammers

Tools that I use repeatedly that make my life easy.

1. notifications.py - to make notifications during long runs.
2. plotting.py - helping functions for matplotlib and plotly.
3. tools.py - statistical functions and pandas.
4. time.py - get time as str fast.
5. print_ascii.py - print my signature


### Installation

pip install git+https://github.com/PTorr/torrs_hammers
pip install -r requirements.txt

pip install torrs-hammers

       ** 
        ** 
         **    
          **     *     
           **   ***    
            ** ******   
             ********* 
             *      *** 
            ****  **** 
           *****  ***  
            ****  **   
             ******     
              ****     
               **
